summaryrefslogtreecommitdiffstats
path: root/knetworkconf/knetworkconf/kaddressvalidator.h
diff options
context:
space:
mode:
Diffstat (limited to 'knetworkconf/knetworkconf/kaddressvalidator.h')
-rw-r--r--knetworkconf/knetworkconf/kaddressvalidator.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/knetworkconf/knetworkconf/kaddressvalidator.h b/knetworkconf/knetworkconf/kaddressvalidator.h
index 5a05d84..fa8b8ca 100644
--- a/knetworkconf/knetworkconf/kaddressvalidator.h
+++ b/knetworkconf/knetworkconf/kaddressvalidator.h
@@ -19,7 +19,7 @@
#define KADDRESSVALIDATOR_H
/*
- Class for validating IP address and nettqmasks, and to calculate network and broadcast values.
+ Class for validating IP address and netmasks, and to calculate network and broadcast values.
The functions to do the last two things where taken from the code of ipcalc.c, made by
Erik Troan <ewt@redhat.com> and Preston Brown <pbrown@redhat.com> from Red Hat Inc.
*/
@@ -43,7 +43,7 @@
#include <netinet/in.h>
#include <tqstring.h>
/**Class that has simple methods for validating IP addresses, nettqmasks, calculating
broadcast and network addresses.
*@author Juan Luis Baptiste
@@ -56,7 +56,7 @@ public:
/** Validates if the address written by the user is a valid one. Return true if it is and false if not. */
static bool isValidIPAddress(TQString addr);
/** Validates if the Nettqmask written by the user is a valid one. Return true if it is and false if not. */
- static bool isNettqmaskValid(TQString addr);
+ static bool isNetmaskValid(TQString addr);
/** Validates if the Network written by the user is a valid one. Return true if it is and false if not. */
static bool isNetworkValid(const TQString &addr);
/** Validates if the Broadcast written by the user is a valid one. Return true if it is and false if not. */
@@ -103,7 +103,7 @@ private: // Private methods
*/
static unsigned long int prefix2tqmask(int prefix);
/** \fn int tqmask2prefix(unsigned long int tqmask)
- \brief calculates the number of bits tqmasked off by a nettqmask.
+ \brief calculates the number of bits masked off by a nettqmask.
This function calculates the significant bits in an IP address as specified by
a nettqmask. See also \ref prefix2tqmask.
@@ -43,7 +43,7 @@
#include <netinet/in.h>
#include <tqstring.h>
-/**Class that has simple methods for validating IP addresses, nettqmasks, calculating
+/**Class that has simple methods for validating IP addresses, netmasks, calculating
broadcast and network addresses.
*@author Juan Luis Baptiste